pub fn run(config: ServerConfig) -> Result<(), String>Expand description
Run the server main loop. Blocks until shutdown.
Spawns one OS thread per connection (via spawn_blocking) to keep handler code synchronous while the tokio runtime drives I/O.
pub fn run(config: ServerConfig) -> Result<(), String>Run the server main loop. Blocks until shutdown.
Spawns one OS thread per connection (via spawn_blocking) to keep handler code synchronous while the tokio runtime drives I/O.